@@ -1,3 +1,29 @@
+/*********************************************************************
+ *
+ * main.cxx
+ * 
+ * Kasumi - a management tool for a private dictionary of anthy
+ * 
+ * Copyright (C) 2004-2006 Takashi Nakamoto
+ * Copyright (C) 2005 Takuro Ashie
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA  02110-1301, USA.
+ * 
+*********************************************************************/
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -13,6 +39,9 @@
 #include "KasumiConfiguration.hxx"
 #include "KasumiException.hxx"
 #include "intl.h"
+extern "C"{  // ad-hoc solution for a defect of Anthy
+#include "anthy/dicutil.h"
+}
 
 using namespace std;
 
@@ -36,8 +65,8 @@ void showHelp(){
 }
 
 void showVersion(){
-  cout << "kasumi " << VERSION << ": a personal dictionary manager for Anthy" << endl;
-  cout << "Copyright (C) 2004-2005 Takashi Nakamoto.\n";
+  cout << "Kasumi " << VERSION << " - a personal dictionary manager for Anthy" << endl;
+  cout << "Copyright (C) 2004-2006 Takashi Nakamoto.\n";
   cout << "This program comes with NO WARRANTY, to the extent permitted " \
           "by law. \nYou may redistribute it under the terms of the GNU " \
           "General Public License; \nsee the file named COPYING for " \
@@ -167,9 +196,12 @@ int main(int argc, char *argv[])
     return 0;
 
   try{
+      anthy_dic_util_init();
+
+    KasumiWordType::initWordTypeList();      
     KasumiConfiguration *conf = new KasumiConfiguration(argc, argv);
 
-    KasumiDic *dic = new KasumiDic(conf->getPropertyValue("DictionaryPath"),conf);
+    KasumiDic *dic = new KasumiDic(conf);
 
     string startupMode = conf->getPropertyValue("StartupMode");
     if(startupMode == string("HELP")){
